@@ -6,25 +6,26 @@ extern crate gl;
 
 use self::gl::types::*;
 use crate::actor::Actor;
+use crate::actor::EventHandler;
 
-pub struct Stage {
+pub struct Stage<'a> {
   width: u32,
   height: u32,
   viewport_width: u32,
   viewport_height: u32,
   visible: bool,
-  pub stage_actor: Actor,
+  pub stage_actor: Actor<'a>,
 }
 
-impl Stage {
-  pub fn new(vw: u32, vh: u32) -> Self {
+impl<'a>  Stage<'a> {
+  pub fn new(vw: u32, vh: u32, evet_handler:  Box<dyn EventHandler + 'a>) -> Self {
     Stage {
       width: 0,
       height: 0,
       viewport_width: vw,
       viewport_height: vh,
       visible: false,
-      stage_actor: Actor::new("stage_actor".to_string(), vw, vh),
+      stage_actor: Actor::new("stage_actor".to_string(), vw, vh, evet_handler)
     }
   }
 
@@ -36,6 +37,13 @@ impl Stage {
     self.visible = visible;
   }
 
+  pub fn handle_input(&mut self, key: usize) {
+     println!("stage key: {}", key);
+
+      self.stage_actor.handle_input(key);
+
+  }
+
   pub fn render(&mut self, shader_program: GLuint) {
     if !self.visible {
       return
@@ -44,7 +52,7 @@ impl Stage {
     self.stage_actor.render(shader_program, None);
   }
 
-  pub fn add_actor(&mut self, mut actor: Actor) -> usize {
+  pub fn add_actor(&mut self, mut actor: Actor<'a>) -> usize {
     actor.init_gl(self.viewport_width, self.viewport_height);
     self.stage_actor.sub_actor_list.push(actor);
 
